@@ -10,7 +10,7 @@ from struct import pack # for network byte order
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 logger = logging.getLogger(__name__)
 
@@ -242,7 +242,7 @@ class Connection(handler.Connection):
         """handle any non websocket requests, normally, you'll want to just fail it
         but sometimes it is handy to be able to override this in a child class to
         handle custom cases (specifically for us, a pingdom check"""
-        return self.reply_invalid(ws_req)
+        return self.reply_invalid(req)
 
     def reply_invalid(self, req):
         """reply to a non websocket request on a websocket connection"""
